@@ -11,13 +11,13 @@ from nonebot.log import logger
 from playwright.async_api import async_playwright
 from sqlalchemy.schema import CreateTable
 from sqlite3 import OperationalError
-from .model import sub_tournament, sqlite_pool
+from .model import sub_tournament, sqlite_pool, init_database
 
 api = 'https://www.scoregg.com/services/api_url.php'
 headers = {
     'accept': 'application/json',
     'accept-encoding': 'gzip, deflate',
-    # 'cookie': 'tgw_l7_route=324afa77be2fbfbd1d30bfb41a867c63; Hm_lvt_7d06c05f2674b5f5fffa6500f4e9da89=1638889938; PHPSESSID=3gb41u6hef1d0hqp1va29abqp6; _uab_collina=163888994040853655457939; Hm_lpvt_7d06c05f2674b5f5fffa6500f4e9da89=1638889941'
+    # 'cookie':
 }
 tournament_params = {
     'api_path': '/services/match/web_tournament_group_list.php',
@@ -68,6 +68,7 @@ class LoLMatch:
         初始化数据库
         :return:
         """
+        await init_database()  # 初始化数据库
         statement = CreateTable(sub_tournament)
         try:
             await sqlite_pool.execute(statement)
